package controllers

import (
	"encoding/json"

	oclib "cloud.o-forge.io/core/oc-lib"
	beego "github.com/beego/beego/v2/server/web"
)

// Operations about compute
type ComputeController struct {
	beego.Controller
}

// @Title Update
// @Description create computes
// @Param	id		path 	string	true		"the compute id you want to get"
// @Param	body		body 	models.compute	true		"The compute content"
// @Success 200 {compute} models.compute
// @router /:id [put]
func (o *ComputeController) Put() {
	// store and return Id or post with UUID
	var res map[string]interface{}
	id := o.Ctx.Input.Param(":id")
	json.Unmarshal(o.Ctx.Input.CopyBody(10000), &res)
	o.Data["json"] = oclib.UpdateOne(oclib.LibDataEnum(oclib.COMPUTE_RESOURCE), res, id)
	o.ServeJSON()
}

// @Title Create
// @Description create compute
// @Param	compute		body 	json	true		"body for compute content (Json format)"
// @Success 200 {compute} models.compute
// @router / [post]
func (o *ComputeController) Post() {
	var res map[string]interface{}
	json.Unmarshal(o.Ctx.Input.CopyBody(10000), &res)
	o.Data["json"] = oclib.StoreOne(oclib.LibDataEnum(oclib.COMPUTE_RESOURCE), res)
	o.ServeJSON()
}

// @Title GetAll
// @Description find compute by id
// @Success 200 {compute} models.compute
// @router / [get]
func (o *ComputeController) GetAll() {
	o.Data["json"] = oclib.LoadAll(oclib.LibDataEnum(oclib.COMPUTE_RESOURCE))
	o.ServeJSON()
}

// @Title Get
// @Description find compute by key word
// @Param	search		path 	string	true		"the search you want to get"
// @Success 200 {compute} models.compute
// @router /search/:search [get]
func (o *ComputeController) Search() {
	search := o.Ctx.Input.Param(":search")
	o.Data["json"] = oclib.Search(nil, search, oclib.LibDataEnum(oclib.COMPUTE_RESOURCE))
	o.ServeJSON()
}

// @Title Get
// @Description find compute by id
// @Param	id		path 	string	true		"the id you want to get"
// @Success 200 {compute} models.compute
// @router /:id [get]
func (o *ComputeController) Get() {
	id := o.Ctx.Input.Param(":id")
	o.Data["json"] = oclib.LoadOne(oclib.LibDataEnum(oclib.COMPUTE_RESOURCE), id)
	o.ServeJSON()
}

// @Title Delete
// @Description delete the compute
// @Param	id		path 	string	true		"The id you want to delete"
// @Success 200 {compute} delete success!
// @router /:id [delete]
func (o *ComputeController) Delete() {
	id := o.Ctx.Input.Param(":id")
	o.Data["json"] = oclib.DeleteOne(oclib.LibDataEnum(oclib.COMPUTE_RESOURCE), id)
	o.ServeJSON()
}
